@@ -16,8 +16,8 @@ from typing import Any, Dict, List, Optional, Tuple
 
 import yaml
 
+from ..core.cache.advanced_cache import AdvancedCache
 from ..core.error_codes import ErrorCode, create_validation_error
-from ..utils.advanced_cache import AdvancedCache
 
 logger = logging.getLogger(__name__)
 
@@ -200,7 +200,6 @@ class ConfigValidator:
         # Check required environment variables
         required_env_vars = {
             "MANUSCRIPT_PATH": {"required": False, "type": "path"},
-            "RXIV_ENGINE": {"required": False, "type": "choice", "choices": ["LOCAL", "DOCKER", "PODMAN"]},
             "DOCKER_AVAILABLE": {"required": False, "type": "boolean"},
         }
 
