@@ -1,10 +1,12 @@
 """Conversion utilities for Rxiv-Maker.
 
 This package contains modules for converting between different formats
-(e.g., Markdown to LaTeX).
+(e.g., Markdown to LaTeX) and processing custom commands including
+Python code execution and blindtext generation.
 """
 
 from .citation_processor import convert_citations_to_latex
+from .custom_command_processor import process_custom_commands
 from .md2tex import (
     convert_markdown_to_latex,
     extract_content_sections,
@@ -16,4 +18,5 @@ __all__ = [
     "convert_markdown_to_latex",
     "convert_citations_to_latex",
     "convert_text_formatting_to_latex",
+    "process_custom_commands",
 ]
