@@ -12,6 +12,8 @@ from .code_processor import (
     protect_code_content,
     restore_protected_code,
 )
+from .comment_processor import preprocess_comments
+from .custom_command_processor import process_custom_commands
 from .figure_processor import (
     convert_equation_references_to_latex,
     convert_figure_references_to_latex,
@@ -34,9 +36,11 @@ from .table_processor import convert_table_references_to_latex, convert_tables_t
 from .text_formatters import (
     convert_subscript_superscript_to_latex,
     escape_special_characters,
+    find_and_replace_python_color,
     process_code_spans,
     protect_bold_outside_texttt,
     protect_italic_outside_texttt,
+    protect_underline_outside_texttt,
     restore_protected_seqsplit,
 )
 from .types import LatexContent, MarkdownContent, ProtectedContent
@@ -46,6 +50,10 @@ from .url_processor import convert_links_to_latex
 def convert_markdown_to_latex(content: MarkdownContent, is_supplementary: bool = False) -> LatexContent:
     r"""Convert basic markdown formatting to LaTeX.
 
+    This function now uses the centralized ContentProcessor for enhanced
+    pipeline management, error handling, and extensibility. Falls back to
+    legacy conversion logic if the ContentProcessor is unavailable or fails.
+
     Args:
         content: The markdown content to convert
         is_supplementary: If True, adds \newpage after figures and tables
@@ -53,7 +61,61 @@ def convert_markdown_to_latex(content: MarkdownContent, is_supplementary: bool =
     Returns:
         LaTeX formatted content
     """
-    # FIRST: Convert fenced code blocks BEFORE protecting backticks
+    # Use the new centralized ContentProcessor for enhanced processing
+    # ContentProcessor is now complete with all processors from legacy logic
+    # TEMPORARY: Re-disable ContentProcessor due to hanging issues with Python execution
+    # Two critical issues discovered:
+    # 1. Python execution errors not being displayed and halting PDF generation
+    # 2. Protected content placeholders not being restored in final output
+    # TODO: Fix ContentProcessor execution flow and protected content restoration
+    use_content_processor = False  # Disabled due to execution and restoration issues
+
+    if use_content_processor:
+        try:
+            from ..core.content_processor import get_content_processor
+
+            processor = get_content_processor()
+            result = processor.process(content, is_supplementary=is_supplementary)
+
+            if result.success:
+                return result.content
+            else:
+                # Log warnings but continue with legacy logic for graceful degradation
+                from ..core.logging_config import get_logger
+
+                logger = get_logger()
+                logger.warning(f"ContentProcessor completed with {len(result.errors)} errors: {result.errors}")
+                logger.warning("Falling back to legacy conversion logic")
+
+        except ImportError:
+            # Fallback for environments where core modules aren't available
+            pass
+        except (AttributeError, ValueError, RuntimeError) as e:
+            # Graceful degradation on content processor errors
+            try:
+                from ..core.logging_config import get_logger
+
+                logger = get_logger()
+                logger.warning(f"ContentProcessor failed: {e}, falling back to legacy conversion")
+            except ImportError:
+                pass  # Continue silently if logging is unavailable
+
+    # Legacy conversion logic (original implementation)
+    # CRITICAL FIRST STEP: Remove HTML comments to prevent any commented content
+    # from being processed by subsequent steps (tables, citations, executable blocks, etc.)
+    # This is essential for security - commented content should NEVER be processed
+    content = preprocess_comments(content)
+
+    # PROTECT TEX BLOCKS: Protect {{tex:...}} blocks from markdown processing
+    # This must happen early to prevent markdown syntax inside tex blocks from being processed
+    content, protected_tex_content = _protect_tex_blocks(content)
+
+    # CRITICAL: Process custom commands (Python/R execution) BEFORE any code protection
+    # This ensures Python code can be extracted properly before LaTeX processing interferes
+    # NOTE: tex blocks are still protected at this point and will be handled specially
+    content = process_custom_commands(content)
+
+    # SECOND: Convert fenced code blocks AFTER Python execution
     content = convert_code_blocks_to_latex(content)
 
     # Process enhanced math blocks ($$...$$ {#eq:id})
@@ -64,6 +126,7 @@ def convert_markdown_to_latex(content: MarkdownContent, is_supplementary: bool =
     protected_backtick_content: ProtectedContent = {}
     protected_tables: ProtectedContent = {}
     protected_markdown_tables: ProtectedContent = {}
+    # Note: protected_tex_content is already populated above
 
     # Protect backtick content and markdown tables BEFORE math protection
     content, protected_backtick_content = _protect_backtick_content(content)
@@ -152,6 +215,15 @@ def convert_markdown_to_latex(content: MarkdownContent, is_supplementary: bool =
     # Finally restore mathematical expressions
     content = restore_math_expressions(content, protected_math)
 
+    # FINAL STEP: Restore {{tex:...}} blocks after all markdown processing is complete
+    # This ensures tex blocks are processed at the very end
+    content = _restore_tex_blocks(content, protected_tex_content)
+
+    # Process only tex commands now that all markdown processing is done
+    from .custom_command_processor import _process_tex_commands
+
+    content = _process_tex_commands(content)
+
     return content
 
 
@@ -194,6 +266,94 @@ def _process_float_barrier_markers(content: MarkdownContent) -> LatexContent:
     return content
 
 
+def _protect_tex_blocks(
+    content: MarkdownContent,
+) -> tuple[LatexContent, ProtectedContent]:
+    """Protect {{tex:...}} blocks from markdown processing, excluding those in backticks."""
+    protected_tex_content: ProtectedContent = {}
+
+    # First, identify all backtick spans to exclude from tex block protection
+    backtick_spans = []
+    i = 0
+    while i < len(content):
+        if content[i] == "`":
+            # Count opening backticks
+            start = i
+            backtick_count = 0
+            while i < len(content) and content[i] == "`":
+                backtick_count += 1
+                i += 1
+
+            # Find matching closing backticks
+            while i < len(content):
+                if content[i] == "`":
+                    # Count closing backticks
+                    closing_count = 0
+                    while i < len(content) and content[i] == "`":
+                        closing_count += 1
+                        i += 1
+
+                    if closing_count == backtick_count:
+                        # Found complete backtick span
+                        backtick_spans.append((start, i))
+                        break
+                else:
+                    i += 1
+            else:
+                # No matching closing backticks found
+                i = start + backtick_count
+        else:
+            i += 1
+
+    def is_inside_backticks(pos: int) -> bool:
+        """Check if position is inside any backtick span."""
+        for start, end in backtick_spans:
+            if start <= pos < end:
+                return True
+        return False
+
+    # Now scan for tex blocks, excluding those inside backtick spans
+    result = []
+    i = 0
+
+    while i < len(content):
+        if content[i : i + 6] == "{{tex:" and not is_inside_backticks(i):
+            # Found tex block outside of backticks
+            brace_count = 2  # Start with {{
+            start = i + 6  # length of "{{tex:"
+            j = start
+            while j < len(content) and brace_count > 0:
+                if content[j] == "{":
+                    brace_count += 1
+                elif content[j] == "}":
+                    brace_count -= 1
+                j += 1
+
+            if brace_count == 0:
+                # Found complete tex block
+                full_block = content[i:j]
+                placeholder = f"XXPROTECTEDTEXBLOCKXX{len(protected_tex_content)}XXPROTECTEDTEXBLOCKXX"
+                protected_tex_content[placeholder] = full_block
+                result.append(placeholder)
+                i = j
+            else:
+                # Incomplete block, treat as regular text
+                result.append(content[i])
+                i += 1
+        else:
+            result.append(content[i])
+            i += 1
+
+    return "".join(result), protected_tex_content
+
+
+def _restore_tex_blocks(content: LatexContent, protected_tex_content: ProtectedContent) -> LatexContent:
+    """Restore {{tex:...}} blocks from placeholders."""
+    for placeholder, original_content in protected_tex_content.items():
+        content = content.replace(placeholder, original_content)
+    return content
+
+
 def _protect_backtick_content(
     content: MarkdownContent,
 ) -> tuple[LatexContent, ProtectedContent]:
@@ -326,9 +486,13 @@ def _process_text_formatting(content: LatexContent, protected_backtick_content:
     # Then convert backticks to texttt with proper underscore handling
     content = process_code_spans(content)
 
-    # Convert bold and italic AFTER processing backticks
+    # Process protected Python color placeholders
+    content = find_and_replace_python_color(content)
+
+    # Convert bold, italic, and underline AFTER processing backticks
     content = protect_bold_outside_texttt(content)
     content = protect_italic_outside_texttt(content)
+    content = protect_underline_outside_texttt(content)
 
     # Convert subscript and superscript formatting
     content = convert_subscript_superscript_to_latex(content)
