@@ -8,6 +8,7 @@ import re
 from pathlib import Path
 
 try:
+    from .. import __version__
     from ..converters.md2tex import extract_content_sections
     from .author_processor import (
         generate_authors_and_affiliations,
@@ -23,6 +24,11 @@ except ImportError:
         generate_extended_author_info,
     )
 
+    try:
+        from .. import __version__
+    except ImportError:
+        __version__ = "unknown"
+
 
 def get_template_path():
     """Get the path to the template file."""
@@ -56,15 +62,32 @@ def get_template_path():
     )
 
 
-def find_supplementary_md():
-    """Find supplementary information file in the manuscript directory."""
-    current_dir = Path.cwd()
-    manuscript_path = os.getenv("MANUSCRIPT_PATH", "MANUSCRIPT")
+def find_supplementary_md(manuscript_path=None):
+    """Find supplementary information file in the manuscript directory.
 
-    # Look for supplementary file: 02_SUPPLEMENTARY_INFO.md
-    supplementary_md = current_dir / manuscript_path / "02_SUPPLEMENTARY_INFO.md"
-    if supplementary_md.exists():
-        return supplementary_md
+    Args:
+        manuscript_path: Path to the manuscript directory (if None, uses PathManager logic)
+    """
+    if manuscript_path:
+        # Use provided manuscript path
+        manuscript_dir = Path(manuscript_path)
+        supplementary_md = manuscript_dir / "02_SUPPLEMENTARY_INFO.md"
+        if supplementary_md.exists():
+            return supplementary_md
+    else:
+        # Legacy fallback for when no path is provided
+        current_dir = Path.cwd()
+        manuscript_path = os.getenv("MANUSCRIPT_PATH", "MANUSCRIPT")
+
+        # First try directly in current directory (when already in manuscript dir)
+        supplementary_md = current_dir / "02_SUPPLEMENTARY_INFO.md"
+        if supplementary_md.exists():
+            return supplementary_md
+
+        # Then try in manuscript_path subdirectory (when called from parent dir)
+        supplementary_md = current_dir / manuscript_path / "02_SUPPLEMENTARY_INFO.md"
+        if supplementary_md.exists():
+            return supplementary_md
 
     return None
 
@@ -117,11 +140,11 @@ def generate_supplementary_cover_page(yaml_metadata):
     return cover_latex
 
 
-def generate_supplementary_tex(output_dir, yaml_metadata=None):
+def generate_supplementary_tex(output_dir, yaml_metadata=None, manuscript_path=None):
     """Generate Supplementary.tex file from supplementary markdown."""
     from ..converters.md2tex import convert_markdown_to_latex
 
-    supplementary_md = find_supplementary_md()
+    supplementary_md = find_supplementary_md(manuscript_path)
     if not supplementary_md:
         # Create empty supplementary file
         supplementary_tex_path = Path(output_dir) / "Supplementary.tex"
@@ -190,19 +213,28 @@ def generate_supplementary_tex(output_dir, yaml_metadata=None):
 % in the class file
 \\renewcommand{\\figurename}{Sup. Fig.}
 \\renewcommand{\\tablename}{Sup. Table}
+% Reset supplementary figure counter to start from 1
+\\setcounter{sfigure}{0}
+% Reset supplementary table counter to start from 1
+\\setcounter{stable}{0}
 
 """
 
     # Process the LaTeX to convert figure environments to sfigure environments
     # Replace \begin{figure} with \begin{sfigure} and \end{figure} with \end{sfigure}
+    # Also handle two-column figures (figure* -> sfigure*)
     # Also preserve \newpage commands that come after figures
     # (with or without line breaks)
+    supplementary_latex = supplementary_latex.replace("\\begin{figure*}", "\\begin{sfigure*}")
     supplementary_latex = supplementary_latex.replace("\\begin{figure}", "\\begin{sfigure}")
     # Handle newpage with line breaks (using escaped backslashes)
+    supplementary_latex = supplementary_latex.replace("\\end{figure*}\n\\newpage", "\\end{sfigure*}\n\\newpage")
     supplementary_latex = supplementary_latex.replace("\\end{figure}\n\\newpage", "\\end{sfigure}\n\\newpage")
     # Handle newpage without line breaks
+    supplementary_latex = supplementary_latex.replace("\\end{figure*}\\newpage", "\\end{sfigure*}\\newpage")
     supplementary_latex = supplementary_latex.replace("\\end{figure}\\newpage", "\\end{sfigure}\\newpage")
     # Handle remaining figure endings
+    supplementary_latex = supplementary_latex.replace("\\end{figure*}", "\\end{sfigure*}")
     supplementary_latex = supplementary_latex.replace("\\end{figure}", "\\end{sfigure}")
 
     # Process the LaTeX to convert table environments to stable environments
@@ -261,7 +293,13 @@ def generate_keywords(yaml_metadata):
 
 def generate_bibliography(yaml_metadata):
     """Generate LaTeX bibliography section from YAML metadata."""
-    bibliography = yaml_metadata.get("bibliography", "03_REFERENCES")
+    bibliography_config = yaml_metadata.get("bibliography", "03_REFERENCES")
+
+    # Handle both dict and string formats for backward compatibility
+    if isinstance(bibliography_config, dict):
+        bibliography = bibliography_config.get("file", "03_REFERENCES")
+    else:
+        bibliography = bibliography_config
 
     # Remove .bib extension if present
     if bibliography.endswith(".bib"):
@@ -377,7 +415,49 @@ def process_template_replacements(template_content, yaml_metadata, article_md):
 
     # Replace content placeholders with extracted sections
     template_content = template_content.replace("<PY-RPL:ABSTRACT>", content_sections.get("abstract", ""))
-    template_content = template_content.replace("<PY-RPL:MAIN-CONTENT>", content_sections.get("main", ""))
+
+    # Handle main/introduction section with proper header and include all custom sections
+    main_section_parts = []
+
+    if content_sections.get("introduction"):
+        # If there's an introduction section, use it with "Introduction" header
+        main_section_content = content_sections["introduction"]
+        main_section_parts.append(f"\\section*{{Introduction}}\n{main_section_content}")
+    elif content_sections.get("main"):
+        # If there's a main section (but no introduction), use it with "Main" header
+        main_section_content = content_sections["main"]
+        main_section_parts.append(f"\\section*{{Main}}\n{main_section_content}")
+
+    # Include all custom sections (sections that don't map to standard academic paper sections)
+    standard_sections = {
+        "abstract",
+        "introduction",
+        "main",
+        "methods",
+        "results",
+        "discussion",
+        "conclusion",
+        "data_availability",
+        "code_availability",
+        "manuscript_preparation",
+        "author_contributions",
+        "acknowledgements",
+        "funding",
+    }
+
+    custom_sections = []
+    for section_key, section_content in content_sections.items():
+        if section_key not in standard_sections and section_content.strip():
+            custom_sections.append(section_content)
+
+    # Add all custom sections to the main section
+    if custom_sections:
+        main_section_parts.extend(custom_sections)
+
+    # Combine all parts into the final main section
+    main_section = "\n\n".join(main_section_parts) if main_section_parts else ""
+
+    template_content = template_content.replace("<PY-RPL:MAIN-SECTION>", main_section)
     template_content = template_content.replace("<PY-RPL:METHODS>", content_sections.get("methods", ""))
 
     # Handle main content sections conditionally
@@ -453,9 +533,7 @@ def process_template_replacements(template_content, yaml_metadata, article_md):
     # Add RχIV-Maker acknowledgment if requested
     acknowledge_rxiv = yaml_metadata.get("acknowledge_rxiv_maker", False)
     if acknowledge_rxiv and not manuscript_prep_content.strip():
-        manuscript_prep_content = (
-            "This manuscript was prepared using {\\color{red}R}$\\chi$iv-Maker~\\cite{saraiva_2025_rxivmaker}."
-        )
+        manuscript_prep_content = f"This manuscript was prepared using {{\\color{{red}}R}}$\\chi$iv-Maker v{__version__}~\\cite{{saraiva_2025_rxivmaker}}."
 
     # Add license information if specified
     license_info = yaml_metadata.get("license", "")
