@@ -685,6 +685,29 @@ class MathValidator(BaseValidator):
             protected,
         )
 
+        # Protect LaTeX code blocks {{tex: ...}}
+        protected = re.sub(
+            r"\{\{tex:.*?\}\}",
+            lambda m: f"XXPROTECTEDCODEXX{len(m.group(0))}XXPROTECTEDCODEXX",
+            protected,
+            flags=re.DOTALL,
+        )
+
+        # Protect Python code blocks {{py: ...}}
+        protected = re.sub(
+            r"\{\{py:.*?\}\}",
+            lambda m: f"XXPROTECTEDCODEXX{len(m.group(0))}XXPROTECTEDCODEXX",
+            protected,
+            flags=re.DOTALL,
+        )
+
+        # Protect inline Python expressions {py: ...}
+        protected = re.sub(
+            r"\{py:[^}]+\}",
+            lambda m: f"XXPROTECTEDCODEXX{len(m.group(0))}XXPROTECTEDCODEXX",
+            protected,
+        )
+
         return protected
 
     def _generate_math_statistics(self) -> dict[str, Any]:
