@@ -4,7 +4,7 @@ import os
 import tempfile
 import unittest
 from pathlib import Path
-from unittest.mock import patch
+from unittest.mock import MagicMock, patch
 
 try:
     import pytest
@@ -22,18 +22,14 @@ except ImportError:
 
     pytest = MockPytest()
 
-try:
-    from rxiv_maker.utils.doi_cache import DOICache
-    from rxiv_maker.validators.base_validator import ValidationLevel
-    from rxiv_maker.validators.doi_validator import DOIValidator
+from rxiv_maker.core.cache.doi_cache import DOICache
+from rxiv_maker.validators.base_validator import ValidationLevel
+from rxiv_maker.validators.doi_validator import DOIValidator
 
-    DOI_VALIDATOR_AVAILABLE = True
-except ImportError:
-    DOI_VALIDATOR_AVAILABLE = False
+DOI_VALIDATOR_AVAILABLE = True
 
 
 @pytest.mark.validation
-@unittest.skipUnless(DOI_VALIDATOR_AVAILABLE, "DOI validator not available")
 class TestDOICache(unittest.TestCase):
     """Test DOI cache functionality."""
 
@@ -108,7 +104,6 @@ class TestDOICache(unittest.TestCase):
 
 
 @pytest.mark.validation
-@unittest.skipUnless(DOI_VALIDATOR_AVAILABLE, "DOI validator not available")
 class TestDOIValidator(unittest.TestCase):
     """Test DOI validator functionality."""
 
@@ -120,42 +115,66 @@ class TestDOIValidator(unittest.TestCase):
         os.makedirs(self.manuscript_dir)
         os.makedirs(self.cache_dir)
 
+        # Create config file to make this a valid manuscript directory
+        config_path = os.path.join(self.manuscript_dir, "00_CONFIG.yml")
+        with open(config_path, "w") as f:
+            f.write("title: Test Manuscript\nauthor: Test Author\n")
+
+        # Store original working directory
+        self.original_cwd = os.getcwd()
+
+    def create_validator(self, **kwargs):
+        """Helper method to create validator in correct directory context."""
+        # Change to manuscript directory for DOIValidator creation
+        os.chdir(self.manuscript_dir)
+        default_kwargs = {"enable_online_validation": False, "cache_dir": self.cache_dir}
+        default_kwargs.update(kwargs)
+        return DOIValidator(self.manuscript_dir, **default_kwargs)
+
     def tearDown(self):
         """Clean up test fixtures."""
         import shutil
 
+        # Restore original working directory
+        os.chdir(self.original_cwd)
         shutil.rmtree(self.temp_dir, ignore_errors=True)
 
     @pytest.mark.fast
     def test_doi_format_validation(self):
         """Test DOI format validation."""
-        validator = DOIValidator(
-            self.manuscript_dir,
-            enable_online_validation=False,
-            cache_dir=self.cache_dir,
-        )
+        # Change to manuscript directory so find_manuscript_directory() works
+        old_cwd = os.getcwd()
+        try:
+            os.chdir(self.manuscript_dir)
+            validator = DOIValidator(
+                self.manuscript_dir,
+                enable_online_validation=False,
+                cache_dir=self.cache_dir,
+            )
 
-        # Test valid DOI formats
-        valid_dois = [
-            "10.1000/test.2023.001",
-            "10.1109/MCSE.2007.55",
-            "10.1093/comjnl/27.2.97",
-            "10.1371/journal.pcbi.1003285",
-        ]
+            # Test valid DOI formats
+            valid_dois = [
+                "10.1000/test.2023.001",
+                "10.1109/MCSE.2007.55",
+                "10.1093/comjnl/27.2.97",
+                "10.1371/journal.pcbi.1003285",
+            ]
 
-        for doi in valid_dois:
-            self.assertTrue(validator.DOI_REGEX.match(doi), f"Valid DOI failed: {doi}")
+            for doi in valid_dois:
+                self.assertTrue(validator.DOI_REGEX.match(doi), f"Valid DOI failed: {doi}")
 
-        # Test invalid DOI formats
-        invalid_dois = [
-            "not-a-doi",
-            "10.test/invalid",
-            "10./invalid",
-            "doi:10.1000/test",
-        ]
+            # Test invalid DOI formats
+            invalid_dois = [
+                "not-a-doi",
+                "10.test/invalid",
+                "10./invalid",
+                "doi:10.1000/test",
+            ]
 
-        for doi in invalid_dois:
-            self.assertFalse(validator.DOI_REGEX.match(doi), f"Invalid DOI passed: {doi}")
+            for doi in invalid_dois:
+                self.assertFalse(validator.DOI_REGEX.match(doi), f"Invalid DOI passed: {doi}")
+        finally:
+            os.chdir(old_cwd)
 
     def test_bib_entry_extraction(self):
         """Test BibTeX entry extraction."""
@@ -186,24 +205,30 @@ class TestDOIValidator(unittest.TestCase):
         with open(os.path.join(self.manuscript_dir, "03_REFERENCES.bib"), "w") as f:
             f.write(bib_content)
 
-        validator = DOIValidator(
-            self.manuscript_dir,
-            enable_online_validation=False,
-            cache_dir=self.cache_dir,
-        )
-        entries = validator._extract_bib_entries(bib_content)
+        # Change to manuscript directory so find_manuscript_directory() works
+        old_cwd = os.getcwd()
+        try:
+            os.chdir(self.manuscript_dir)
+            validator = DOIValidator(
+                self.manuscript_dir,
+                enable_online_validation=False,
+                cache_dir=self.cache_dir,
+            )
+            entries = validator._extract_bib_entries(bib_content)
 
-        # Should extract 3 entries
-        self.assertEqual(len(entries), 3)
+            # Should extract 3 entries
+            self.assertEqual(len(entries), 3)
 
-        # Check entries with DOIs
-        entries_with_doi = [e for e in entries if "doi" in e]
-        self.assertEqual(len(entries_with_doi), 2)
+            # Check entries with DOIs
+            entries_with_doi = [e for e in entries if "doi" in e]
+            self.assertEqual(len(entries_with_doi), 2)
 
-        # Check specific entry
-        test1_entry = next(e for e in entries if e["entry_key"] == "test1")
-        self.assertEqual(test1_entry["title"], "Test Article One")
-        self.assertEqual(test1_entry["doi"], "10.1000/test1.2023.001")
+            # Check specific entry
+            test1_entry = next(e for e in entries if e["entry_key"] == "test1")
+            self.assertEqual(test1_entry["title"], "Test Article One")
+            self.assertEqual(test1_entry["doi"], "10.1000/test1.2023.001")
+        finally:
+            os.chdir(old_cwd)
 
     def test_validation_without_bib_file(self):
         """Test validation when bibliography file doesn't exist."""
@@ -321,12 +346,37 @@ class TestDOIValidator(unittest.TestCase):
             shutil.rmtree(unique_temp, ignore_errors=True)
 
     @pytest.mark.fast
+    @patch("requests.Session.get")
+    @patch("requests.Session.head")
+    @patch("requests.get")
+    @patch("requests.head")
+    @patch("crossref_commons.retrieval.get_publication_as_json")
     @patch.object(DOIValidator, "_check_network_connectivity", return_value=True)
     @patch.object(DOIValidator, "_validate_doi_metadata")
-    def test_validation_with_api_error(self, mock_validate_metadata, mock_network_check):
+    def test_validation_with_api_error(
+        self,
+        mock_validate_metadata,
+        mock_network_check,
+        mock_crossref,
+        mock_requests_head,
+        mock_requests_get,
+        mock_session_head,
+        mock_session_get,
+    ):
         """Test validation when metadata validation fails for all sources."""
-        # Mock metadata validation to return error indicating no sources available
+        # Configure mocks to prevent actual network calls
+        import requests
 
+        mock_response = MagicMock()
+        mock_response.status_code = 200
+        mock_response.json.return_value = {}
+        mock_session_get.return_value = mock_response
+        mock_session_head.return_value = mock_response
+        mock_requests_get.return_value = mock_response
+        mock_requests_head.return_value = mock_response
+        mock_crossref.side_effect = requests.exceptions.RequestException("Mocked network error")
+
+        # Mock metadata validation to return error indicating no sources available
         from rxiv_maker.validators.base_validator import ValidationError, ValidationLevel
 
         mock_validate_metadata.return_value = [
@@ -376,10 +426,36 @@ class TestDOIValidator(unittest.TestCase):
         )
 
     @pytest.mark.fast
+    @patch("requests.Session.get")
+    @patch("requests.Session.head")
+    @patch("requests.get")
+    @patch("requests.head")
+    @patch("crossref_commons.retrieval.get_publication_as_json")
     @patch.object(DOIValidator, "_check_network_connectivity", return_value=True)
     @patch.object(DOIValidator, "_validate_doi_metadata")
-    def test_datacite_fallback_success(self, mock_validate_metadata, mock_network_check):
+    def test_datacite_fallback_success(
+        self,
+        mock_validate_metadata,
+        mock_network_check,
+        mock_crossref,
+        mock_requests_head,
+        mock_requests_get,
+        mock_session_head,
+        mock_session_get,
+    ):
         """Test successful DataCite fallback when CrossRef fails."""
+        # Configure mocks to prevent actual network calls
+        mock_response = MagicMock()
+        mock_response.status_code = 200
+        mock_response.json.return_value = {}
+        mock_session_get.return_value = mock_response
+        mock_session_head.return_value = mock_response
+        mock_requests_get.return_value = mock_response
+        mock_requests_head.return_value = mock_response
+        import requests
+
+        mock_crossref.side_effect = requests.exceptions.RequestException("Mocked network error")
+
         # Mock successful DataCite validation
         from rxiv_maker.validators.base_validator import ValidationError, ValidationLevel
 
@@ -404,29 +480,31 @@ class TestDOIValidator(unittest.TestCase):
         with open(os.path.join(self.manuscript_dir, "03_REFERENCES.bib"), "w") as f:
             f.write(bib_content)
 
-        validator = DOIValidator(
-            self.manuscript_dir,
-            enable_online_validation=True,
-            cache_dir=self.cache_dir,
-            ignore_ci_environment=True,
-            force_validation=True,
-        )
-        result = validator.validate()
+        # Change to manuscript directory so find_manuscript_directory() works
+        old_cwd = os.getcwd()
+        try:
+            os.chdir(self.manuscript_dir)
+            validator = DOIValidator(
+                self.manuscript_dir,
+                enable_online_validation=True,
+                cache_dir=self.cache_dir,
+                ignore_ci_environment=True,
+                force_validation=True,
+            )
+            result = validator.validate()
 
-        # Should have success message for DataCite validation
-        success_messages = [error.message for error in result.errors if error.level.value == "success"]
-        self.assertTrue(any("DataCite" in msg for msg in success_messages))
+            # Should have success message for DataCite validation
+            success_messages = [error.message for error in result.errors if error.level.value == "success"]
+            self.assertTrue(any("DataCite" in msg for msg in success_messages))
 
-        # Should call the metadata validation method
-        mock_validate_metadata.assert_called()
+            # Should call the metadata validation method
+            mock_validate_metadata.assert_called()
+        finally:
+            os.chdir(old_cwd)
 
     def test_title_cleaning(self):
         """Test title cleaning for comparison."""
-        validator = DOIValidator(
-            self.manuscript_dir,
-            enable_online_validation=False,
-            cache_dir=self.cache_dir,
-        )
+        validator = self.create_validator()
 
         # Test LaTeX command removal
         latex_title = "Test \\textbf{bold} and \\textit{italic} text"
@@ -445,11 +523,7 @@ class TestDOIValidator(unittest.TestCase):
 
     def test_journal_cleaning(self):
         """Test journal name cleaning for comparison."""
-        validator = DOIValidator(
-            self.manuscript_dir,
-            enable_online_validation=False,
-            cache_dir=self.cache_dir,
-        )
+        validator = self.create_validator()
 
         # Test ampersand removal
         journal_name = "Science \\& Engineering"
@@ -474,6 +548,15 @@ class TestDOIValidator(unittest.TestCase):
         os.makedirs(unique_cache)
 
         try:
+            # Create required config file for manuscript directory detection
+            config_content = """
+title: "Test Manuscript"
+authors:
+  - name: "Test Author"
+"""
+            with open(os.path.join(unique_manuscript, "00_CONFIG.yml"), "w") as f:
+                f.write(config_content)
+
             # Create a simple bib file with valid DOI format
             bib_content = """
 @article{cached_test,
@@ -488,6 +571,10 @@ class TestDOIValidator(unittest.TestCase):
             with open(os.path.join(unique_manuscript, "03_REFERENCES.bib"), "w") as f:
                 f.write(bib_content)
 
+            # Change to manuscript directory for auto-detection to work
+            original_cwd = os.getcwd()
+            os.chdir(unique_manuscript)
+
             # Test with offline validation to avoid network issues in parallel tests
             validator1 = DOIValidator(
                 unique_manuscript, enable_online_validation=False, cache_dir=unique_cache, ignore_ci_environment=True
@@ -512,16 +599,14 @@ class TestDOIValidator(unittest.TestCase):
             self.assertEqual(result1.metadata["total_dois"], result2.metadata["total_dois"])
 
         finally:
+            # Restore original working directory
+            os.chdir(original_cwd)
             # Clean up temporary directory
             shutil.rmtree(unique_temp, ignore_errors=True)
 
     def test_similarity_threshold(self):
         """Test title similarity threshold."""
-        validator = DOIValidator(
-            self.manuscript_dir,
-            enable_online_validation=False,
-            cache_dir=self.cache_dir,
-        )
+        validator = self.create_validator()
 
         # Test similar titles (should pass)
         title1 = "A Study of Machine Learning Applications"
@@ -541,7 +626,6 @@ class TestDOIValidator(unittest.TestCase):
 
 
 @pytest.mark.validation
-@unittest.skipUnless(DOI_VALIDATOR_AVAILABLE, "DOI validator not available")
 class TestDOIValidatorIntegration(unittest.TestCase):
     """Test DOI validator integration with citation validator."""
 
@@ -557,23 +641,38 @@ class TestDOIValidatorIntegration(unittest.TestCase):
 
         shutil.rmtree(self.temp_dir, ignore_errors=True)
 
+    @patch("requests.Session.get")
+    @patch("requests.Session.head")
+    @patch("requests.get")
+    @patch("requests.head")
     @patch("crossref_commons.retrieval.get_publication_as_json")
-    def test_citation_validator_integration(self, mock_crossref):
+    def test_citation_validator_integration(
+        self, mock_crossref, mock_requests_head, mock_requests_get, mock_session_head, mock_session_get
+    ):
         """Test DOI validation integration with citation validator."""
         try:
             from rxiv_maker.validators.citation_validator import CitationValidator
         except ImportError:
             self.skipTest("CitationValidator not available")
 
+        # Configure mocks to prevent actual network calls
+        mock_response = MagicMock()
+        mock_response.status_code = 200
+        mock_response.json.return_value = {}
+        mock_session_get.return_value = mock_response
+        mock_session_head.return_value = mock_response
+        mock_requests_get.return_value = mock_response
+        mock_requests_head.return_value = mock_response
+
         # Mock CrossRef response
-        mock_response = {
+        crossref_response = {
             "message": {
                 "title": ["Integrated Test Article"],
                 "container-title": ["Integration Journal"],
                 "published-print": {"date-parts": [[2023]]},
             }
         }
-        mock_crossref.return_value = mock_response
+        mock_crossref.return_value = crossref_response
 
         # Create manuscript files
         main_content = """
