@@ -57,17 +57,21 @@ class TestMarkdownToLatexConversion:
     def test_markdown_inside_backticks_preserved(self):
         """Test that markdown syntax inside backticks is preserved literally."""
         # Test various markdown syntaxes inside backticks
+        # Updated to match improved detokenize implementation for special character handling
         test_cases = [
-            ("This is `*italic*` text.", r"\texttt{*italic*}"),
-            ("This is `**bold**` text.", r"\texttt{**bold**}"),
+            # Markdown syntax (*, **) gets detokenize treatment
+            ("This is `*italic*` text.", r"\texttt{\detokenize{*italic*}}"),
+            ("This is `**bold**` text.", r"\texttt{\detokenize{**bold**}}"),
             (
                 "Code: `*emphasis* and **strong**` here.",
-                r"\texttt{\seqsplit{\textit{emphasis} and \textbf{strong}}}",
+                r"\texttt{\detokenize{*emphasis* and **strong**}}",
             ),
+            # Underscores get standard LaTeX escaping (not markdown syntax)
             ("Inline: `_underscore_` formatting.", r"\texttt{\_underscore\_}"),
+            # Mixed markdown syntax gets detokenize treatment
             (
                 "Complex: `**bold** and *italic* together`.",
-                r"\texttt{\seqsplit{\textbf{bold} and \textit{italic} together}}",
+                r"\texttt{\detokenize{**bold** and *italic* together}}",
             ),
         ]
 
@@ -117,7 +121,7 @@ class TestFigureConversion:
         result = convert_figures_to_latex(markdown)
 
         assert r"\begin{figure}[!ht]" in result
-        assert r"\includegraphics[width=0.8\linewidth]{Figures/test/test.png}" in result
+        assert r"\includegraphics[width=0.800\linewidth" in result
         assert r"\caption{Test Caption}" in result
         assert r"\label{fig:test}" in result
         assert r"\end{figure}" in result
@@ -127,8 +131,8 @@ class TestFigureConversion:
         markdown = "![Simple Caption](FIGURES/simple.png)"
         result = convert_figures_to_latex(markdown)
 
-        assert r"\begin{figure}[ht]" in result
-        assert r"\includegraphics[width=\linewidth]{Figures/simple/simple.png}" in result
+        assert r"\begin{figure}[!htbp]" in result
+        assert r"\includegraphics[width=\linewidth,keepaspectratio,draft=false]{FIGURES/simple.png}" in result
         assert r"\caption{Simple Caption}" in result
         assert r"\end{figure}" in result
 
@@ -246,6 +250,28 @@ class TestURLEscaping:
         result = escape_url_for_latex(url)
         assert result == expected
 
+    def test_bare_url_in_parentheses(self):
+        """Test that bare URLs in parentheses don't include the closing parenthesis."""
+        from rxiv_maker.converters.url_processor import convert_links_to_latex
+
+        markdown = "(see https://example.com)"
+        result = convert_links_to_latex(markdown)
+        # The URL should be https://example.com, not https://example.com)
+        assert "\\url{https://example.com}" in result
+        assert "\\url{https://example.com)}" not in result
+        # The closing parenthesis should remain in the text
+        assert result == "(see \\url{https://example.com})"
+
+    def test_bare_url_in_parentheses_with_hash(self):
+        """Test that bare URLs with hash symbols in parentheses are handled correctly."""
+        from rxiv_maker.converters.url_processor import convert_links_to_latex
+
+        markdown = "(visit https://example.com/page#section for details)"
+        result = convert_links_to_latex(markdown)
+        # The URL should end at the closing parenthesis, not include it
+        assert "\\url{https://example.com/page\\#section}" in result
+        assert "\\url{https://example.com/page\\#section)}" not in result
+
 
 class TestListConversion:
     """Test markdown list conversion to LaTeX."""
@@ -733,9 +759,9 @@ class TestSubscriptSuperscriptFormatting:
         markdown = "The code `H~2~O` and `x^2^` should remain unchanged."
         result = convert_markdown_to_latex(markdown, is_supplementary=False)
 
-        # Should contain code spans with original syntax
-        assert "\\texttt{H~2~O}" in result
-        assert "\\texttt{x^2^}" in result
+        # Should contain code spans with original syntax using detokenize (since ~ and ^ are markdown syntax)
+        assert "\\texttt{\\detokenize{H~2~O}}" in result
+        assert "\\texttt{\\detokenize{x^2^}}" in result
         # Should not be converted to LaTeX formatting
         assert "\\textsubscript{2}" not in result
         assert "\\textsuperscript{2}" not in result
